summaryrefslogtreecommitdiff
path: root/cpio/test
diff options
context:
space:
mode:
authorMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:00:04 +0900
committerMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:00:04 +0900
commit5fa19d2720aef965e88d297f5c58cac556c41f03 (patch)
treef28f96bd3295fcb698530d502b983f576166702c /cpio/test
parent35af4d958fe5df6fb43a8deba5a4658d17cf2226 (diff)
downloadlibarchive-5fa19d2720aef965e88d297f5c58cac556c41f03.tar.gz
Switch an external program for lzip decompression from "lunzip" to
"lzip -d".
Diffstat (limited to 'cpio/test')
-rw-r--r--cpio/test/main.c6
-rw-r--r--cpio/test/test.h4
-rw-r--r--cpio/test/test_extract_cpio_lz.c2
3 files changed, 6 insertions, 6 deletions
diff --git a/cpio/test/test_extract_cpio_lz.c b/cpio/test/test_extract_cpio_lz.c
index d0ed24b2..4454e7b1 100644
--- a/cpio/test/test_extract_cpio_lz.c
+++ b/cpio/test/test_extract_cpio_lz.c
@@ -32,7 +32,7 @@ DEFINE_TEST(test_extract_cpio_lz)
extract_reference_file(reffile);
f = systemf("%s -it < %s >test.out 2>test.err", testprog, reffile);
- if (f == 0 || canLunzip()) {
+ if (f == 0 || canLzip()) {
assertEqualInt(0, systemf("%s -i < %s >test.out 2>test.err",
testprog, reffile));
diff --git a/cpio/test/main.c b/cpio/test/main.c
index 6db2b420..889847ed 100644
--- a/cpio/test/main.c
+++ b/cpio/test/main.c
@@ -1903,15 +1903,15 @@ canLrzip(void)
}
/*
* Can this platform run the lunzip program?
*/
int
-canLunzip(void)
+canLzip(void)
{
static int tested = 0, value = 0;
if (!tested) {
tested = 1;
- if (systemf("lunzip -V %s", redirectArgs) == 0)
+ if (systemf("lzip -V %s", redirectArgs) == 0)
value = 1;
}
return (value);
@@ -1903,15 +1903,15 @@ canLrzip(void)
}
/*
- * Can this platform run the lunzip program?
+ * Can this platform run the lzip program?
*/
int
diff --git a/cpio/test/test.h b/cpio/test/test.h
index a15b8e92..823d6541 100644
--- a/cpio/test/test.h
+++ b/cpio/test/test.h
@@ -278,8 +278,8 @@ int canGzip(void);
/* Return true if this platform can run the "lrzip" program. */
int canLrzip(void);
-/* Return true if this platform can run the "lunzip" program. */
-int canLunzip(void);
+/* Return true if this platform can run the "lzip" program. */
+int canLzip(void);
/* Return true if this platform can run the "unlzma" program. */
int canUnlzma(void);